try:
    import mmh3
except ImportError:
    from .lib import pymmh3 as mmh3


class Bucketer(object):
    def __init__(self):
        return

    def bucketing(self, bucket, user_id):
        slot_number = self._slot_number(user_id, bucket.seed, bucket.slotSize)

        for slot in bucket.slots:
            if slot.contains(slot_number):
                return slot

        return None

    def _slot_number(self, user_id, seed, slot_size):
        hash_value = mmh3.hash(user_id, seed)
        return abs(hash_value) % abs(slot_size)



from six import string_types
from six import integer_types


def is_non_empty_string(input_id_key):
    if input_id_key and isinstance(input_id_key, string_types):
        return True

    return False


def is_non_zero_and_empty_int(input_id_key):
    if input_id_key and isinstance(input_id_key, integer_types) and input_id_key > 0:
        return True

    return False
